aboutsummaryrefslogtreecommitdiff
path: root/src/include/gnunet_disk_lib.h
diff options
context:
space:
mode:
authorharsha <harsha@140774ce-b5e7-0310-ab8b-a85725594a96>2012-11-07 16:56:55 +0000
committerharsha <harsha@140774ce-b5e7-0310-ab8b-a85725594a96>2012-11-07 16:56:55 +0000
commite8b107d67a898745057eec122ce916755c0786fc (patch)
treed85027a39b401f7e1cd766a3f8d9f992393d0517 /src/include/gnunet_disk_lib.h
parent7c941fff7dbe4bde54a7caf99dbda40db07e21ab (diff)
Parameterized directory listing permission check
git-svn-id: https://gnunet.org/svn/gnunet@24823 140774ce-b5e7-0310-ab8b-a85725594a96
Diffstat (limited to 'src/include/gnunet_disk_lib.h')
-rw-r--r--src/include/gnunet_disk_lib.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/include/gnunet_disk_lib.h b/src/include/gnunet_disk_lib.h
index 91cc1587a5..73736be31e 100644
--- a/src/include/gnunet_disk_lib.h
+++ b/src/include/gnunet_disk_lib.h
@@ -663,17 +663,18 @@ GNUNET_DISK_directory_create_for_file (const char *filename);
/**
* Test if "fil" is a directory that can be accessed.
* Will not print an error message if the directory
* does not exist. Will log errors if GNUNET_SYSERR is
* returned.
*
* @param fil filename to test
* @return GNUNET_YES if yes, GNUNET_NO if does not exist, GNUNET_SYSERR
* on any error and if exists but not directory
*/
int
-GNUNET_DISK_directory_test (const char *fil);
+GNUNET_DISK_directory_test (const char *fil, int is_listable);
/**
@@ -663,17 +663,18 @@ GNUNET_DISK_directory_create_for_file (const char *filename);
/**
- * Test if "fil" is a directory that can be accessed.
- * Will not print an error message if the directory
- * does not exist. Will log errors if GNUNET_SYSERR is
- * returned.
+ * Test if "fil" is a directory and readable. Also check if the directory is
+ * listable. Will not print an error message if the directory does not exist.
+ * Will log errors if GNUNET_SYSERR is returned (i.e., a file exists with the
+ * same name).
*
* @param fil filename to test
@@ -663,17 +663,18 @@ GNUNET_DISK_directory_create_for_file (const char *filename);
*
* @param fil filename to test
- * @return GNUNET_YES if yes, GNUNET_NO if does not exist, GNUNET_SYSERR
- * on any error and if exists but not directory
+ * @param is_listable GNUNET_YES to additionally check if "fil" is listable
+ * @return GNUNET_YES if yes, GNUNET_NO if not, GNUNET_SYSERR if it
+ * does not exist
*/
int